# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: annotations.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x61nnotations.proto\x1a google/protobuf/descriptor.proto\"o\n\tRateLimit\x12\x13\n\x06per_ip\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x15\n\x08per_user\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06global\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\t\n\x07_per_ipB\x0b\n\t_per_userB\t\n\x07_global*\x93\x01\n\tAuthLevel\x12\x16\n\x12\x41UTH_LEVEL_UNKNOWN\x10\x00\x12\x13\n\x0f\x41UTH_LEVEL_OPEN\x10\x01\x12\x15\n\x11\x41UTH_LEVEL_JAILED\x10\x02\x12\x15\n\x11\x41UTH_LEVEL_SECURE\x10\x03\x12\x15\n\x11\x41UTH_LEVEL_EDITOR\x10\x05\x12\x14\n\x10\x41UTH_LEVEL_ADMIN\x10\x04:2\n\tsensitive\x12\x1d.google.protobuf.FieldOptions\x18\xd0\x86\x03 \x01(\x08:1\n\x08is_token\x12\x1d.google.protobuf.FieldOptions\x18\xd1\x86\x03 \x01(\x08:A\n\nauth_level\x12\x1f.google.protobuf.ServiceOptions\x18\xd1\x86\x03 \x01(\x0e\x32\n.AuthLevel:I\n\x12rate_limit_default\x12\x1f.google.protobuf.ServiceOptions\x18\xd3\x86\x03 \x01(\x0b\x32\n.RateLimit:K\n\x14rate_limit_aggregate\x12\x1f.google.protobuf.ServiceOptions\x18\xd4\x86\x03 \x01(\x0b\x32\n.RateLimit:@\n\nrate_limit\x12\x1e.google.protobuf.MethodOptions\x18\xd2\x86\x03 \x01(\x0b\x32\n.RateLimitb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'annotations_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_AUTHLEVEL']._serialized_start=169
  _globals['_AUTHLEVEL']._serialized_end=316
  _globals['_RATELIMIT']._serialized_start=55
  _globals['_RATELIMIT']._serialized_end=166
# @@protoc_insertion_point(module_scope)
